@@ -12,7 +12,6 @@ try:
 except ImportError:
     DJANGO_VERSION = None
 
-
 # Register database schemes in URLs.
 urlparse.uses_netloc.append('postgres')
 urlparse.uses_netloc.append('postgresql')
@@ -42,19 +41,12 @@ SCHEMES = {
     'sqlite': 'django.db.backends.sqlite3',
     'oracle': 'django.db.backends.oracle',
     'oraclegis': 'django.contrib.gis.db.backends.oracle',
-    'redshift': 'django_redshift_backend'
+    'redshift': 'django_redshift_backend',
+    'postgres': 'django.db.backends.postgresql',
+    'postgresql': 'django.db.backends.postgresql',
+    'pgsql': 'django.db.backends.postgresql'
 }
 
-# https://docs.djangoproject.com/en/2.0/releases/2.0/#id1
-if DJANGO_VERSION and DJANGO_VERSION < (2, 0):
-    SCHEMES['postgres'] = 'django.db.backends.postgresql_psycopg2'
-    SCHEMES['postgresql'] = 'django.db.backends.postgresql_psycopg2'
-    SCHEMES['pgsql'] = 'django.db.backends.postgresql_psycopg2'
-else:
-    SCHEMES['postgres'] = 'django.db.backends.postgresql'
-    SCHEMES['postgresql'] = 'django.db.backends.postgresql'
-    SCHEMES['pgsql'] = 'django.db.backends.postgresql'
-
 
 def config(env=DEFAULT_ENV, default=None, engine=None, conn_max_age=0, ssl_require=False):
     """Returns configured DATABASE dictionary from DATABASE_URL."""
@@ -141,10 +133,10 @@ def parse(url, engine=None, conn_max_age=0, ssl_require=False):
 
     # Support for Postgres Schema URLs
     if 'currentSchema' in options and engine in (
-        'django.contrib.gis.db.backends.postgis',
-        'django.db.backends.postgresql_psycopg2',
-        'django.db.backends.postgresql',
-        'django_redshift_backend',
+            'django.contrib.gis.db.backends.postgis',
+            'django.db.backends.postgresql_psycopg2',
+            'django.db.backends.postgresql',
+            'django_redshift_backend',
     ):
         options['options'] = '-c search_path={0}'.format(options.pop('currentSchema'))
 
